==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/packageableelement/impl/ComponentResultSetSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.packageableelement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentResultSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ComponentVisibilitySetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ElementTypeConstants;


public class ComponentResultSetSetImpl extends InstanceSet<ComponentResultSetSet,ComponentResultSet> implements ComponentResultSetSet {

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ComponentResultSet componentresultset : this ) componentresultset.setName( m_Name );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ComponentResultSet componentresultset : this ) componentresultset.setId( ref_Id );
    }
    @Override
    public void setType( ElementTypeConstants m_Type ) throws XtumlException {
        for ( ComponentResultSet componentresultset : this ) componentresultset.setType( m_Type );
    }


    // selections
    @Override
    public C_CSet R8007_held_by_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( ComponentResultSet componentresultset : this ) c_cset.add( componentresultset.R8007_held_by_C_C() );
        return c_cset;
    }
    @Override
    public ComponentVisibilitySet R8008_made_up_of_ComponentVisibility() throws XtumlException {
        ComponentVisibilitySet componentvisibilityset = new ComponentVisibilitySetImpl();
        for ( ComponentResultSet componentresultset : this ) componentvisibilityset.addAll( componentresultset.R8008_made_up_of_ComponentVisibility() );
        return componentvisibilityset;
    }


    @Override
    public ComponentResultSet nullElement() {
        return ComponentResultSetImpl.EMPTY_COMPONENTRESULTSET;
    }

    @Override
    public ComponentResultSetSet emptySet() {
      return new ComponentResultSetSetImpl();
    }

    @Override
    public ComponentResultSetSet value() {
        return this;
    }

    @Override
    public List<ComponentResultSet> elements() {
        ComponentResultSet[] elements = toArray(new ComponentResultSet[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/packageableelement/impl/ComponentResultSetSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.packageableelement.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_CSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_CSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentResultSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentResultSetSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.ComponentVisibilitySet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.ComponentVisibilitySetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ElementTypeConstants;


public class ComponentResultSetSetImpl extends InstanceSet<ComponentResultSetSet,ComponentResultSet> implements ComponentResultSetSet {

    public ComponentResultSetSetImpl() {
    }

    public ComponentResultSetSetImpl(Comparator<? super ComponentResultSet> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ComponentResultSet componentresultset : this ) componentresultset.setId( ref_Id );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ComponentResultSet componentresultset : this ) componentresultset.setName( m_Name );
    }
    @Override
    public void setType( ElementTypeConstants m_Type ) throws XtumlException {
        for ( ComponentResultSet componentresultset : this ) componentresultset.setType( m_Type );
    }


    // selections
    @Override
    public C_CSet R8007_held_by_C_C() throws XtumlException {
        C_CSet c_cset = new C_CSetImpl();
        for ( ComponentResultSet componentresultset : this ) c_cset.add( componentresultset.R8007_held_by_C_C() );
        return c_cset;
    }
    @Override
    public ComponentVisibilitySet R8008_made_up_of_ComponentVisibility() throws XtumlException {
        ComponentVisibilitySet componentvisibilityset = new ComponentVisibilitySetImpl();
        for ( ComponentResultSet componentresultset : this ) componentvisibilityset.addAll( componentresultset.R8008_made_up_of_ComponentVisibility() );
        return componentvisibilityset;
    }


    @Override
    public ComponentResultSet nullElement() {
        return ComponentResultSetImpl.EMPTY_COMPONENTRESULTSET;
    }

    @Override
    public ComponentResultSetSet emptySet() {
      return new ComponentResultSetSetImpl();
    }

    @Override
    public ComponentResultSetSet emptySet(Comparator<? super ComponentResultSet> comp) {
      return new ComponentResultSetSetImpl(comp);
    }

    @Override
    public ComponentResultSetSet value() {
        return this;
    }

    @Override
    public List<ComponentResultSet> elements() {
        ComponentResultSet[] elements = toArray(new ComponentResultSet[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
